@@ -2,6 +2,6 @@
 from relpath import add_import_path
 add_import_path("../")
 # task management tool
-import tskr
+from tskr import tskr
 
 tskr()
